@@ -4,8 +4,8 @@
 // Author:      Mattia Barbon
 // Modified by:
 // Created:     21/03/2001
-// RCS-ID:      $Id: ht_constants.cpp 2057 2007-06-18 23:03:00Z mbarbon $
-// Copyright:   (c) 2001, 2003-2006 Mattia Barbon
+// RCS-ID:      $Id: ht_constants.cpp 2087 2007-07-21 12:09:40Z mbarbon $
+// Copyright:   (c) 2001, 2003-2007 Mattia Barbon
 // Licence:     This program is free software; you can redistribute it and/or
 //              modify it under the same terms as Perl itself
 /////////////////////////////////////////////////////////////////////////////
@@ -25,6 +25,14 @@ double html_constant( const char* name, int arg )
 
     switch( fl )
     {
+    case 'E':
+#if WXPERL_W_VERSION_GE( 2, 7, 2 )
+        r( wxEVT_COMMAND_HTML_CELL_CLICKED );
+        r( wxEVT_COMMAND_HTML_CELL_HOVER );
+        r( wxEVT_COMMAND_HTML_LINK_CLICKED );
+#endif
+        break;
+
     case 'H':
         r( wxHF_TOOLBAR );
         r( wxHF_FLATTOOLBAR );
